"""Provides Arrow field for Marshmallow."""

import arrow
from marshmallow import fields


class ArrowField(fields.Field):
    """
    An isoformatted datetime string.

    Arrow objects are converted to and from isoformatted strings
    by `Schema.dump` and `Schema.load` respectively.
    """

    default_error_messages = {
        'invalid_object': 'Invalid arrow object.',
        'invalid_datetime': 'Unable to parse datetime.',
    }

    def _serialize(self, value, attr, obj):
        if value is None:
            return None

        return value.isoformat()

    def _deserialize(self, value, attr, data):
        if not value:
            raise self.fail('invalid_object')

        try:
            return arrow.get(value)
        except arrow.parser.ParserError:
            raise self.fail('invalid_datetime')



"""A Marshmallow Custom Field for Arrow objects."""

from setuptools import setup

setup(
    name='Marshmallow-Arrow',
    version='1.0',
    url='https://github.com/youversion/marshmallow_arrow',
    download_url='https://github.com/youversion/marshmallow_arrow/archive/master.zip',
    license='MIT',
    author='Alex Ronoquillo',
    author_email='developers@youversion.com',
    description='A Marshmallow Custom Field for Arrow objects.',
    long_description=__doc__,
    packages=['marshmallow_arrow'],
    zip_safe=False,
    include_package_data=True,
    platforms='any',
    install_requires=[
        'arrow',
        'marshmallow'
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
    keywords=['marshmallow', 'arrow'],
    test_suite='tests',
)
